==> fxt-2006.09.24.tbz: include/fxt/bits-all.h <==
#if !defined HAVE_BITS_ALL_H__
#define      HAVE_BITS_ALL_H__

//: bit wizardry

#include "bits/bitsperlong.h"

#include "bits/bitasm.h"
#if 0  // for automatic testing
#include "bits/bitasm-i386.h"
#include "bits/bitasm-amd64.h"
#include "bits/bitasm-sse.h"
#endif // 0

#include "bits/cswap.h"

#include "bits/bitcount.h"
#include "bits/bitswap.h"
#include "bits/bitlow.h"
#include "bits/bithigh.h"
#include "bits/bit2pow.h"
#include "bits/bitsubset.h"
//#include "bits/bitsubsetgray.h"
#include "bits/revbin.h"
#include "bits/revbin-upd.h"
#include "bits/graycode.h"
#include "bits/nextgray.h"
#include "bits/parity.h"
#include "bits/grsnegative.h"
#include "bits/tinyfactors.h"

#include "bits/bitperiodic.h"
#include "bits/bitrotate.h"
#include "bits/bitcyclic-minmax.h"
#include "bits/bitcyclic-dist.h"
#include "bits/bitcyclic-match.h"
#include "bits/bitcyclic-period.h"
#include "bits/bitcyclic-xor.h"

#include "bits/bit2adic.h"
#include "bits/negbin.h"
#include "bits/bin2paul.h"

#include "bits/bitcombcolex.h"
//#include "bits/bitcomblex.h"
#include "bits/bitcombminchange.h"
#include "bits/bit2composition.h"
#include "bits/bitlex.h"
#include "bits/bitnecklace.h"
#include "bits/parenwords.h"

#include "bits/fibrep.h"
#include "bits/bitfibgray.h"

#include "bits/zerobyte.h"
#include "bits/branchless.h"

#include "bits/bitmrotate.h"

#include "bits/bitsequency.h"
#include "bits/bittest.h"
#include "bits/bitcopy.h"
#include "bits/bitblock.h"
#include "bits/bitmisc.h"
#include "bits/bitzip.h"
#include "bits/bitgraypermute.h"
#include "bits/bitgather.h"
#include "bits/bitseparate.h"
#include "bits/greencode.h"
#include "bits/graypower.h"
#include "bits/bittransforms.h"
#include "bits/blue-fixed-points.h"
#include "bits/bitxtransforms.h"

#include "bits/hilbert.h"
#include "bits/zorder.h"

#include "bits/bitset2set.h"

#include "bits/crc32.h"
#include "bits/crc64.h"
#include "bits/tcrc64.h"
#include "bits/pcrc64.h"

#include "bits/colormix.h"
#include "bits/colormixp.h"
#include "bits/colormix-fl.h"

#include "bits/printbin.h"
#include "bits/printbitset.h"


#endif // !defined HAVE_BITS_ALL_H__

==> fxt-2008.08.17.tbz: include/fxt/bits-all.h <==
#if !defined HAVE_BITS_ALL_H__
#define      HAVE_BITS_ALL_H__

//: bit wizardry

#include "bits/bitsperlong.h"

#include "bits/bitasm.h"
#if 0  // for automatic testing
#include "bits/bitasm-i386.h"
#include "bits/bitasm-amd64.h"
#include "bits/bitasm-sse.h"
#endif // 0

#include "bits/cswap.h"

#include "bits/evenodd.h"

#include "bits/bitcount.h"
#include "bits/bitswap.h"
#include "bits/bitlow.h"
#include "bits/bithigh.h"
#include "bits/bit2pow.h"
#include "bits/bitsubsetq.h"
#include "bits/bitsubset.h"
#include "bits/bitsubset-gray.h"
#include "bits/revbin.h"
#include "bits/revbin-upd.h"
#include "bits/graycode.h"
#include "bits/nextgray.h"
#include "bits/parity.h"
#include "bits/thue-morse.h"
#include "bits/grsnegative.h"
#include "bits/tinyfactors.h"

#include "bits/bitperiodic.h"
#include "bits/bitrotate.h"
#include "bits/bitcyclic-minmax.h"
#include "bits/bitcyclic-dist.h"
#include "bits/bitcyclic-match.h"
#include "bits/bitcyclic-period.h"
#include "bits/bitcyclic-xor.h"

#include "bits/bit2adic.h"
#include "bits/negbin.h"
#include "bits/bin2naf.h"

#include "bits/bitcombcolex.h"
//#include "bits/bitcomblex.h"
#include "bits/bitcombminchange.h"
#include "bits/bitcombshifts.h"
//#include "bits/bit2composition.h"
#include "bits/bitlex.h"
#include "bits/bit-necklace.h"
#include "bits/parenwords.h"

#include "bits/fibrep.h"
#include "bits/bitfibgray.h"

#include "bits/zerobyte.h"
#include "bits/branchless.h"

#include "bits/bitmrotate.h"

#include "bits/bitsequency.h"
#include "bits/bittest.h"
#include "bits/bitcopy.h"
#include "bits/bitblock.h"
#include "bits/bit-isolate.h"
#include "bits/bitzip.h"
#include "bits/bitbutterfly.h"
#include "bits/bitgraypermute.h"
#include "bits/bitgather.h"
#include "bits/bitseparate.h"
#include "bits/revgraycode.h"
#include "bits/graypower.h"
#include "bits/bittransforms.h"
#include "bits/blue-fixed-points.h"
#include "bits/bitxtransforms.h"

#include "bits/hilbert.h"
#include "bits/zorder.h"

#include "bits/bitset2set.h"

#include "bits/crc32.h"
#include "bits/crc64.h"
#include "bits/tcrc64.h"
#include "bits/pcrc64.h"

#include "bits/colormix.h"
#include "bits/colormixp.h"
#include "bits/colormix-fl.h"

#include "bits/printbin.h"
#include "bits/printbitset.h"


#endif // !defined HAVE_BITS_ALL_H__
